PROJECT = "HTTP"
VERSION = "1.0.0"

BSP = misc.getType():upper() -- 硬件类型,具体到模组型号,ZL401
HW = rtos.hw():upper()       -- 硬件类型,具体到系列型号，ZL400,ZL500


log.setLevel(1)
log.info("HW PLAT IS", HW)

-- 定时打印信息
sys.timerLoopStart(function()
    log.info("mem sys", rtos.meminfo("sys"))
    log.info("mem lua", rtos.meminfo())

    log.info("BSP", BSP)
    log.info("TS", os.time() * 1000)

    if HW == "ZL400" then
        log.info("IMEI", misc.getImei())     -- 模组IMEI
        log.info("ICCID", misc.getIccid())   -- SIM 卡ICCID
        log.info("CSQ", misc.getCsq())       -- 信号
        log.info("SIM", misc.getSimStatus()) -- SIM卡状态
        log.info("IMSI", misc.getImsi())     -- SIM IMSI
    elseif HW == "ZL500" then
        log.info("IMEI", misc.getImei())
        log.info("NETIF", sock.netif())
        log.info("IP", sock.ip())
        log.info("MASK", sock.netmask())
        log.info("GW", sock.gw())
        log.info("DNS", sock.dns())
    else
        log.error("error hardware type")
    end
end, 30000)

-- 网络状态，4G入网LED闪烁，否则常亮
local netled, linkled

if HW == "ZL400" then
    netled = gpio.setup(13, 0) -- output
    linkled = gpio.setup(8, 0)
elseif HW == "ZL500" then
    netled = gpio.setup(33, 0) -- output
    linkled = gpio.setup(12, 0)
end

-- -- gpio输出测试
sys.taskInit(function()
    while true do
        while not sock.isReady() do
            netled(1)
            linkled(1)
            sys.wait(1000)
        end

        netled(0)
        linkled(1)
        sys.wait(1000)
        netled(1)
        linkled(0)
        sys.wait(1000)
    end
end)

local utils = require "utils"

local respHandler = function(ret, code, headers, body)
    -- body
    log.debug("HTTP recv over", id, code, ret)
    sys.publish("HTTP_OVER")
end

local function postMultipartFormData(url, params)
    local boundary = "----WebKitFormBoundary" .. os.time()
    local req_headers = {
        ["Content-Type"] = "multipart/form-data; boundary=" .. boundary,
    }
    local body = {}

    -- 解析拼接 body
    for k, v in pairs(params) do
        if k == "texts" then
            local bodyText = ""
            for kk, vv in pairs(v) do
                print(kk, vv)
                bodyText = bodyText ..
                    "--" ..
                    boundary .. "\r\nContent-Disposition: form-data; name=\"" .. kk .. "\"\r\n\r\n" .. vv .. "\r\n"
            end
            table.insert(body, bodyText)
        elseif k == "files" then
            local contentType =
            {
                txt = "text/plain",       -- 文本
                jpg = "image/jpeg",       -- JPG 格式图片
                jpeg = "image/jpeg",      -- JPEG 格式图片
                png = "image/png",        -- PNG 格式图片
                gif = "image/gif",        -- GIF 格式图片
                html = "image/html",      -- HTML
                json = "application/json" -- JSON
            }

            for kk, vv in pairs(v) do
                if type(vv) == "table" then
                    for i = 1, #vv do
                        print(kk, vv[i])
                        table.insert(body,
                            "--" ..
                            boundary ..
                            "\r\nContent-Disposition: form-data; name=\"" ..
                            kk ..
                            "\"; filename=\"" ..
                            vv[i]:match("[^%/]+%w$") ..
                            "\"\r\nContent-Type: " .. contentType[vv[i]:match("%.(%w+)$")] .. "\r\n\r\n")
                        table.insert(body, io.readFile(vv[i]))
                        table.insert(body, "\r\n")
                    end
                else
                    print(kk, vv)
                    table.insert(body,
                        "--" ..
                        boundary ..
                        "\r\nContent-Disposition: form-data; name=\"" ..
                        kk ..
                        "\"; filename=\"" ..
                        vv:match("[^%/]+%w$") .. "\"\r\nContent-Type: " .. contentType[vv:match("%.(%w+)$")] ..
                        "\r\n\r\n")
                    table.insert(body, io.readFile(vv))
                    table.insert(body, "\r\n")
                end
            end
        end
    end
    table.insert(body, "--" .. boundary .. "--\r\n")
    body = table.concat(body)
    log.info("headers: ", "\r\n" .. json.encode(req_headers), type(body))
    log.info("body: " .. body:len() .. "\r\n" .. body)
    local code, headers, body = http.request("POST", url,
        {
            timeout = 15,        -- 单位秒
            body = body,         -- post才有body
            type = 2,
            header = req_headers -- body参数类型，1表单，2json
        },
        respHandler
    )
    log.info("http.post", code, headers, body)
end



local function postJpg(url, params, pic)
    local boundary = "----WebKitFormBoundary" .. os.time()

    local req_headers = table.setHeader({ ["Content-Type"] = "multipart/form-data; boundary=" .. boundary })
    local body = {}

    -- 解析拼接 body

    local contentType =
    {
        txt = "text/plain",       -- 文本
        jpg = "image/jpeg",       -- JPG 格式图片
        jpeg = "image/jpeg",      -- JPEG 格式图片
        png = "image/png",        -- PNG 格式图片
        gif = "image/gif",        -- GIF 格式图片
        html = "image/html",      -- HTML
        json = "application/json" -- JSON
    }


    -- print(kk, vv)
    log.info("post file", params.files)
    table.insert(body,
        "--" ..
        boundary ..
        "\r\nContent-Disposition: form-data; name=\"" ..
        "uploadFile" ..
        "\"; filename=\"" ..
        "capture" .. os.time() .. ".jpeg" .. "\"\r\nContent-Type: " .. "image/jpeg" ..
        "\r\n\r\n")
    table.insert(body, pic)
    table.insert(body, "\r\n")



    table.insert(body, "--" .. boundary .. "--\r\n")
    body = table.concat(body)
    -- log.info("headers: ", "\r\n" .. json.encode(req_headers), type(body))
    -- log.info("body: " .. body:len() .. "\r\n" .. body)
    http.req("POST", url,
        {
            timeout = 15,        -- 单位秒
            body = body,         -- post才有body
            type = 2,
            header = req_headers -- body参数类型，1表单，2json
        },
        respHandler
    )
end



log.warn("cam init status", cam.init())
cam.start()


sys.taskInit(function()
    -- 等待联网成功
    while true do
        while true do
            while not sock.isReady() do sys.wait(200) end
            sys.wait(6000)
            log.info("start capture")

            local pic = cam.capture()

            log.info(" capture result, len=", pic and #pic or 0)
            if pic then
                postJpg(
                    "http://7q642v.natappfree.cc/api/v1/cap/upload",
                    {
                        files = "/luadb/luatos_uploadFile.txt",
                    },
                    pic
                )
            end
            sys.wait(5000)
        end
        sys.wait(5000)
    end
end)

-- 用户代码已结束---------------------------------------------
-- 结尾总是这一句
while true do sys.eventloop() end
