PROJECT = "CRON"
VERSION = "1.0.0"

BSP = misc.getType():upper() -- 硬件类型,具体到模组型号,ZL401
HW = rtos.hw():upper() -- 硬件类型,具体到系列型号，ZL400,ZL500

log.info("HW PLAT IS", HW)

sys.taskInit(function()
    local retry = 50
    while not sock.isReady() and retry > 0 do
        sys.wait(200)
        retry = retry - 1
    end
    sock.ntpSync()
end)

-- 定时打印信息
sys.timerLoopStart(function()
    log.info("mem sys", rtos.meminfo("sys"))
    log.info("mem lua", rtos.meminfo())

    log.info("BSP", BSP)
    log.info("TS", os.time() * 1000)

    if HW == "ZL400" then
        log.info("IMEI", misc.getImei()) -- 模组IMEI
        log.info("ICCID", misc.getIccid()) -- SIM 卡ICCID
        log.info("CSQ", misc.getCsq()) -- 信号
        log.info("SIM", misc.getSimStatus()) -- SIM卡状态
        log.info("IMSI", misc.getImsi()) -- SIM IMSI
    elseif HW == "ZL500" then
        log.info("IMEI", misc.getImei())
        log.info("NETIF", sock.netif())
        log.info("IP", sock.ip())
        log.info("MASK", sock.netmask())
        log.info("GW", sock.gw())
        log.info("DNS", sock.dns())

    else
        log.error("error hardware type")
    end

end, 1000)

-- 网络状态，4G入网LED闪烁，否则常亮
local netled, linkled

if HW == "ZL400" then
    netled = gpio.setup(13, 0) -- output
    linkled = gpio.setup(8, 0)

elseif HW == "ZL500" then
    netled = gpio.setup(33, 0) -- output
    linkled = gpio.setup(12, 0)
end

local core = require("lcronc")
if not core then
    log.error("bsp not support cron")
else
    local lcron = require("lcron")
    log.info("start test cron")

    lcron.add("name1", "0/5 * * * * *",
              function() log.info("hello cron! 5s") end)
    lcron.add("name2", "* * * * * *", function() log.info("hello cron2! 1s") end)

    -- lcron.delete("name2")

    -- wait for 1 sec
    log.info("start cron timer")
    lcron.start(1000)
    -- lcron.delete("name1")
    -- lcron.delete("name666") -- not exist
end

while true do sys.eventloop() end

