PROJECT = "NET"
VERSION = "1.0.0"

BSP = misc.getType():upper() -- 硬件类型,具体到模组型号,ZL401
HW = rtos.hw():upper()       -- 硬件类型,具体到系列型号，ZL400,ZL500

log.info("HW PLAT IS", HW)

-- 网络状态，4G入网LED闪烁，否则常亮
if HW == "ZL400" then
    netled = gpio.setup(13, 0) -- output
    linkled = gpio.setup(8, 0)
elseif HW == "ZL500" then
    netled = gpio.setup(33, 0) -- output
    linkled = gpio.setup(12, 0)
end

-- 连上了服务器link再亮
linkled(0)

sys.taskInit(function()
    while true do
        while not sock.isReady() do
            netled(0)
            sys.wait(200)
            netled(1)
            sys.wait(200)
        end

        netled(1)
        sys.wait(1000)
    end
end)

local host = "115.159.225.58"
local port = 1883
local client = "client"
local username = "admin"
local pswd = "admin"

local keepAlive = 200 * 1000 --单位ms
local cleansession = 1
local reconnectTime = 2000   --单位ms
local mqrtry = 10            -- 重连次数

local willtopic = "/will"
local willqos = 1
local willretain = 0
local willmsg = "will msg test"

local id = 1
local mqttc, conretry

-- 主要的流程
local function mqttProc()
    -- wait network ready
    while not sock.isReady() do sys.wait(200) end

    -- 新建实例
    mqttc = mqtt.tcp(host, port, client, username, pswd, keepAlive,
        cleansession, reconnectTime)

    -- 遗嘱的设置
    mqttc:will(willtopic, willqos, willretain, willmsg)

    -- mqtt发布handle
    local function mqttPubFun(topic, d)
        if not d or not topic or not mqttc:pub(topic, d) then
            return false
        end
        log.debug("MQTT 发布的数据:", id, topic, d)
        return true
    end

    -- 意外断开
    local disconnectFunc = function()
        log.warn("mqtt disconnect,wait reconnect", conretry, mqrtry)
        linkled(0)
    end
    -- 重连handle
    local reconnectFunc =
        function(id, res) -- res指示是重连失败还是成功
            if res then
                --  连接成功
                linkled(1)
                conretry = mqrtry -- 连续10次连不上，30s,重启
                log.info("mqtt reconnect result", mqttc:stat())
            else
                -- 连接失败
                linkled(0)
                conretry = conretry - 1
                log.info("mqtt reconnect failed", mqttc:stat())
                if conretry == 0 then
                    -- 网络有问题，需要重启
                    sys.timerStart(sys.restart, 2000, "mqtt reconnect fail!")
                end
            end
        end

    local errorFunc = function()
        -- body
        log.error("mqtt error,  chanel", id)
    end

    local recvFunc = function(id, topic, data)
        -- body
        log.info("订阅的消息-----:", topic)

        -- 发布回去
        mqttPubFun("/public/pub11", data)
    end

    -- 更新配置
    -- mqttc:auth(client, username, pswd)
    -- mqttc:host(host)
    -- mqttc:port(port)

    mqttc:on("disconnect", disconnectFunc)
    mqttc:on("recon", reconnectFunc)
    mqttc:on("error", errorFunc)
    mqttc:on("recv", recvFunc)
    log.info("mqtt start connect!")

    -- first connect
    conretry = 10 -- 连续10次连不上，30s,重启
    while not mqttc:connect() and conretry > 0 do
        log.error("mqtt reconnect", conretry)
        sys.wait(3000)
        conretry = conretry - 1
    end
    if conretry == 0 then
        -- 网络有问题，需要重启
        sys.timerStart(sys.restart, 2000, "Net is broken, mqtt connect fail!")
    end

    -- link灯指示
    linkled(1)
    log.info("mqtt connect success", mqttc:stat())

    -- sub topic
    -- log.info("mqtt sub sta", mqt:sub("testtopic", 0)) -- 1 topic sub

    -- 订阅主题
    -- subqos = 1
    -- mqttc:sub("/testtopic1", subqos)
    -- mqttc:sub("/testtopic2", subqos)
    -- 等同于
    local subarray = { ["/public/test1"] = 1, ["/public/test2"] = 1 } -- {topic = qos}
    mqttc:sublist(subarray)
end

sys.taskInit(mqttProc)

-- 用户代码已结束---------------------------------------------
-- 结尾总是这一句
while true do sys.eventloop() end
