PROJECT = "NET"
VERSION = "1.0.0"

BSP = misc.getType():upper() -- 硬件类型,具体到模组型号,ZL401
HW = rtos.hw():upper()       -- 硬件类型,具体到系列型号，ZL400,ZL500

log.info("HW PLAT IS", HW)

-- 网络状态，4G入网LED闪烁，否则常亮
if HW == "ZL400" then
    netled = gpio.setup(13, 0) -- output
    linkled = gpio.setup(8, 0)
elseif HW == "ZL500" then
    netled = gpio.setup(33, 0) -- output
    linkled = gpio.setup(12, 0)
end

-- 连上了服务器link再亮
linkled(0)

sys.taskInit(function()
    while true do
        while not sock.isReady() do
            netled(0)
            sys.wait(200)
            netled(1)
            sys.wait(200)
        end

        netled(1)
        sys.wait(1000)
    end
end)

local host = "192.168.10.22" -- 花生壳测试地址
local port = 7777

-- 新建TCP Client 对象
local so = sock.tcp()
-- 新建UDP Client 对象
-- local so = sock.udp()

sys.taskInit(function()
    while not sock.isReady() do sys.wait(200) end
    sys.wait(3000)
    if HW == "ZL500" then
        sock.ntpSync() -- 4G的无需手动ntp
    end

    if so then
        log.info("start tcp stask")

        local dpp = pack.pack("bbbA", 10, 15, 4, "123")
        log.info("packtest0" .. dpp)

        -- 服务器地址
        so:host(host)
        so:port(port)

        so:recon(2000, 10)          -- 重连间隔时间单位ms, 重启之前的重连次数
        so:keepAlive(60 * 1000, 10) -- 应用层心跳时间ms。发数据在回调里面操作，底层会自动启用链接层TCP KEEPALIVE

        local connectHandle = function()
            log.info("sock connet success", so:id())

            -- led指示
            linkled(1)
            -- 连接上发注册包
            so:send("CMD,GROUP,AXCV")
        end

        local recvHandle = function(sid, data)
            log.info("netc recv", sid, data)
        end

        local myBeatPre = "testBBBB"
        -- 演示，闭包，函数，生成心跳包
        local genBeat = function() return myBeatPre .. os.time() end

        local keepAliveHandle = function()
            -- 发心跳
            so:send(genBeat())
            log.error("keepAliveHandle", so:id())
        end

        local offlineHandle = function()
            -- led指示
            linkled(0)
            log.error("sock is disconnect", id) -- auto reconnect
        end

        local errorHandle = function()
            log.error("sock is broken, id=", so:id())
            -- sys.restart("sock is broken") -- 当连续重连达到重连次数后，进入error状态
        end

        -- 注册回调函数
        so:on("connect", connectHandle)
        so:on("recv", recvHandle)
        so:on("keepAlive", keepAliveHandle)
        so:on("error", errorHandle) -- 重连次数达到设定报错
        so:on("close", offlineHandle)

        if so:connect() then
            log.info("sock status ", so:status())

            -- 测试消息发送
            local function mesgTest()
                log.info("mesgTest", so:status())
                if so:status() then
                    so:send("msg ts:" .. os.time())
                end
            end
            -- sys.timerLoopStart(mesgTest, 5000) --定时发消息测试
        else
            log.error("sock connect error", so:status())
        end

        -- so:close() -- 主动关闭
    end
end)

-- 用户代码已结束---------------------------------------------
-- 结尾总是这一句
while true do sys.eventloop() end
